@@ -256,7 +256,8 @@ class WorkspaceRow:
             if width_sum == 12:
                 default_width = 0
             else:
-                default_width = int(12 - width_sum / sum(1 for component in self.components if component.width is None))
+                default_width = self.components[0].width if len(self.components) == 1 else \
+                    int(12 - width_sum / sum(1 for component in self.components if component.width is None))
             for i, component in enumerate(self.components):
                 if i == components_length - 1 and not component.width:
                     if isinstance(component, WorkspaceColumn):
@@ -311,7 +312,8 @@ class Workspace:
                  selector_components: List[Component] = None,
                  disclaimer: str = None,
                  maintainers: List[str] = None,
-                 call_to_action: Union[WorkspaceCallToAction, Dict] = None):
+                 call_to_action: Union[WorkspaceCallToAction, Dict] = None,
+                 tags: List[str] = None):
         self.__id = None
         self.__name = name
         self.__rows = rows or []
@@ -323,6 +325,7 @@ class Workspace:
         self.__maintainers = maintainers or []
         self.__tabs = tabs or []
         self.__call_to_action = call_to_action
+        self.__tags = tags or []
 
     @classmethod
     def get_by_id(cls, workspace_id: str) -> 'Workspace':
@@ -342,7 +345,7 @@ class Workspace:
         elif self.__alias:
             id_ = get(GsSession.current._get(f'{API}?alias={self.__alias}'), 'results.0.id')
             if id_:
-                self.__id = GsSession.current._put(f'{API}/{id_}', self.as_dict(), request_headers=HEADERS)
+                self.__id = GsSession.current._put(f'{API}/{id_}', self.as_dict(), request_headers=HEADERS)['id']
             else:
                 self.__id = GsSession.current._post(API, self.as_dict(), request_headers=HEADERS)['id']
 
@@ -460,6 +463,18 @@ class Workspace:
     def call_to_action(self, value):
         self.__call_to_action = value
 
+    @property
+    def tags(self):
+        return self.__tags
+
+    @tags.setter
+    def tags(self, value):
+        self.__tags = value
+
+    @property
+    def id(self):
+        return self.__id
+
     @classmethod
     def _parse(cls, layout: str, workspace_components: List[Dict]):
         current_str = ''
@@ -564,8 +579,6 @@ class Workspace:
             parameters['tabs'] = [tab.as_dict() for tab in self.__tabs]
         if self.__disclaimer:
             parameters['disclaimer'] = self.__disclaimer
-        if self.__description:
-            parameters['description'] = self.__description
 
         dict_ = {
             'name': self.__name,
@@ -581,6 +594,10 @@ class Workspace:
                 dict_['entitlements'] = self.__entitlements.to_dict()
             else:
                 dict_['entitlements'] = self.__entitlements
+        if len(self.__tags):
+            dict_['tags'] = self.__tags
+        if self.__description:
+            dict_['description'] = self.__description
 
         return dict_
 
