@@ -15,14 +15,15 @@ under the License.
 """
 
 from typing import Tuple
+
 from gs_quant.backtests.triggers import *
 from gs_quant.backtests.generic_engine import GenericEngine
-from gs_quant.backtests.generic_price_engine import GenericPriceEngine
+from gs_quant.backtests.predefined_asset_engine import PredefinedAssetEngine
 from gs_quant.backtests.equity_vol_engine import EquityVolEngine
 from gs_quant.base import Priceable
 
 
-backtest_engines = [GenericEngine, GenericPriceEngine, EquityVolEngine]
+backtest_engines = [GenericEngine(), PredefinedAssetEngine(), EquityVolEngine()]
 
 
 class Strategy(object):
