@@ -13,35 +13,40 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-from abc import ABC, ABCMeta, abstractmethod
 import builtins
-from collections import namedtuple
 import copy
-from dataclasses import Field, InitVar, MISSING, dataclass, field, fields, replace
-from dataclasses_json import global_config
-from dataclasses_json.core import _is_supported_generic, _decode_generic
-import dataclasses_json.core
 import datetime as dt
-from enum import EnumMeta
-from inflection import camelize, underscore
-import inspect
-import keyword
 import logging
-import numpy as np
+from abc import ABC, ABCMeta, abstractmethod
+from collections import namedtuple
+from dataclasses import Field, InitVar, MISSING, dataclass, field, fields, replace
+from enum import EnumMeta
+from functools import update_wrapper
 from typing import Iterable, Mapping, Optional, Union
 
+import numpy as np
+from dataclasses_json import config, global_config
+from dataclasses_json.core import _decode_generic, _is_supported_generic
 from gs_quant.context_base import ContextBase, ContextMeta
-from gs_quant.json_convertors import encode_date_or_str, decode_date_or_str, decode_optional_date, encode_datetime,\
+from gs_quant.json_convertors import encode_date_or_str, decode_date_or_str, decode_optional_date, encode_datetime, \
     decode_datetime, decode_float_or_str, decode_instrument, encode_dictable
-
+from inflection import camelize, underscore
 
 _logger = logging.getLogger(__name__)
 
 __builtins = set(dir(builtins))
-__iskeyword = keyword.iskeyword
 __getattribute__ = object.__getattribute__
 __setattr__ = object.__setattr__
 
+_rename_cache = {}
+
+def exclude_none(o):
+    return o is None
+
+
+def exlude_always(_o):
+    return True
+
 
 def is_iterable(o, t):
     return isinstance(o, Iterable) and all(isinstance(it, t) for it in o)
@@ -51,6 +56,40 @@ def is_instance_or_iterable(o, t):
     return isinstance(o, t) or is_iterable(o, t)
 
 
+def _get_underscore(arg):
+    if arg not in _rename_cache:
+        _rename_cache[arg] = underscore(arg)
+
+    return _rename_cache[arg]
+
+def handle_camel_case_args(cls):
+    init = cls.__init__
+
+    def wrapper(self, *args, **kwargs):
+        normalised_kwargs = {}
+
+        for arg, value in kwargs.items():
+            if not arg.isupper():
+                snake_case_arg = _get_underscore(arg)
+                if snake_case_arg != arg and snake_case_arg in kwargs:
+                    raise ValueError('{} and {} both specified'.format(arg, snake_case_arg))
+
+                arg = snake_case_arg
+
+            arg = cls._field_mappings().get(arg, arg)
+            normalised_kwargs[arg] = value
+
+        return init(self, *args, **normalised_kwargs)
+
+    cls.__init__ = update_wrapper(wrapper=wrapper, wrapped=init)
+
+    return cls
+
+
+field_metadata = config(exclude=exclude_none)
+name_metadata = config(exclude=exlude_always)
+
+
 class RiskKey(namedtuple('RiskKey', ('provider', 'date', 'market', 'params', 'scenario', 'risk_measure'))):
 
     @property
@@ -96,17 +135,19 @@ class DictBase(HashableDict):
             if invalid_arg is not None:
                 raise AttributeError(f"'{self.__class__.__name__}' has no attribute '{invalid_arg}'")
 
-        super().__init__(*args, **{camelize(k, uppercase_first_letter=False): v for k, v in kwargs.items()})
+        super().__init__(*args, **{camelize(k, uppercase_first_letter=False): v for k, v in kwargs.items()
+                                   if v is not None})
 
     def __getitem__(self, item):
         return super().__getitem__(camelize(item, uppercase_first_letter=False))
 
     def __setitem__(self, key, value):
-        return super().__setitem__(camelize(key, uppercase_first_letter=False), value)
+        if value is not None:
+            return super().__setitem__(camelize(key, uppercase_first_letter=False), value)
 
     def __getattr__(self, item):
         if self._PROPERTIES:
-            if underscore(item) in self._PROPERTIES:
+            if _get_underscore(item) in self._PROPERTIES:
                 return self.get(item)
         elif item in self:
             return self[item]
@@ -116,7 +157,7 @@ class DictBase(HashableDict):
     def __setattr__(self, key, value):
         if key in dir(self):
             return super().__setattr__(key, value)
-        elif self._PROPERTIES and underscore(key) not in self._PROPERTIES:
+        elif self._PROPERTIES and _get_underscore(key) not in self._PROPERTIES:
             raise AttributeError(f"'{self.__class__.__name__}' has no attribute '{key}'")
 
         self[key] = value
@@ -126,70 +167,9 @@ class DictBase(HashableDict):
         return cls._PROPERTIES
 
 
-def fix_args(cls):
-    # Rather unfortunate: prior to the refactor to use dataclasses, 'name' was a non-property argument
-    # Adding it add post_init() to base to allow it to be passed, puts it as the first postional argument
-    # and breaks backward compatibility. This can be fixed using the kw_only argument, which sadly was not added
-    # until later versions than Python 3.7 (though it seems to be in the 3.6 backport)
-    #
-    # Additionally, some classes actually have a field called 'name', we need to use Base.name_ so positional passing
-    # continues to work
-
-    init = cls.__init__
-    signature = inspect.signature(init)
-    add_name = not any(p for p in signature.parameters.values() if p.name == 'name')
-
-    if add_name:
-        name_param = inspect.Parameter('name', inspect.Parameter.POSITIONAL_OR_KEYWORD, default=None,
-                                       annotation=Optional[str])
-        params = tuple(signature.parameters.values()) + (name_param,)
-        signature = signature.replace(parameters=params)
-
-    def wrapper(self, *args, name: Optional[str] = None, **kwargs):
-        normalised_kwargs = {}
-
-        # Handle legacy use of passing args as camel case
-
-        for arg, value in kwargs.items():
-            if not arg.isupper():
-                snake_case_arg = underscore(arg)
-                if snake_case_arg != arg and snake_case_arg in kwargs:
-                    raise ValueError('{} and {} both specified'.format(arg, snake_case_arg))
-
-                arg = snake_case_arg
-
-            arg = cls._field_mappings().get(arg, arg)
-            normalised_kwargs[arg] = value
-
-        init(self, *args, **normalised_kwargs)
-
-        if name is not None:
-            self.name = name
-
-    wrapper.__name__ = init.__name__
-    wrapper.__qualname__ = init.__qualname__
-    wrapper.__doc__ = init.__doc__
-    wrapper.__module__ = init.__module__
-
-    if add_name:
-        cls.__doc__ = cls.__doc__[:-1] + f', name: Union[str, NoneType] = None)'
-        wrapper.__annotations__ = {**{'name': Optional[str]}, **init.__annotations__}
-
-    wrapper.__signature__ = signature
-
-    cls.__init__ = wrapper
-    cls.__base_dataclass_eq__ = cls.__eq__
-    cls.__eq__ = cls.__eq_with_name__
-
-    return cls
-
-
-@dataclass
 class Base(ABC):
     """The base class for all generated classes"""
 
-    name_: InitVar[str] = field(init=False, default=None)
-
     __fields_by_name = None
     __field_mappings = None
 
@@ -199,11 +179,8 @@ class Base(ABC):
         if item.startswith('_') or item in fields_by_name:
             return __getattribute__(self, item)
 
-        if item == 'name':
-            return __getattribute__(self, 'name_')
-
         # Handle setting via camelCase names (legacy behaviour) and field mappings from disallowed names
-        snake_case_item = underscore(item)
+        snake_case_item = _get_underscore(item)
         field_mappings = __getattribute__(self, '_field_mappings')()
         snake_case_item = field_mappings.get(snake_case_item, snake_case_item)
 
@@ -214,7 +191,7 @@ class Base(ABC):
 
     def __setattr__(self, key, value):
         # Handle setting via camelCase names (legacy behaviour)
-        snake_case_key = underscore(key)
+        snake_case_key = _get_underscore(key)
         snake_case_key = self._field_mappings().get(snake_case_key, snake_case_key)
         fld = self._fields_by_name().get(snake_case_key)
 
@@ -224,9 +201,6 @@ class Base(ABC):
 
             key = snake_case_key
             value = self.__coerce_value(fld.type, value)
-            self._property_changed(key, value)
-        elif key == 'name':
-            key = 'name_'
 
         __setattr__(self, key, value)
 
@@ -236,9 +210,6 @@ class Base(ABC):
 
         return super().__repr__()
 
-    def __eq_with_name__(self, other):
-        return isinstance(other, Base) and self.name_ == other.name_ and self.__base_dataclass_eq__(other)
-
     @classmethod
     def __coerce_value(cls, typ: type, value):
         if isinstance(value, np.generic):
@@ -281,9 +252,6 @@ class Base(ABC):
             cls.__field_mappings = field_mappings
         return cls.__field_mappings
 
-    def _property_changed(self, prop: str, value):
-        pass
-
     def clone(self, **kwargs):
         """
             Clone this object, overriding specified values
@@ -299,9 +267,7 @@ class Base(ABC):
             >>>
             >>> new_cap = cap.clone(cap_rate=0.01)
         """
-        ret = replace(self, **kwargs)
-        ret.name_ = self.name_
-        return ret
+        return replace(self, **kwargs)
 
     @classmethod
     def properties(cls) -> set:
@@ -351,6 +317,7 @@ class Base(ABC):
                 __setattr__(self, fld.name, __getattribute__(instance, fld.name))
 
 
+@dataclass
 class Priceable(Base):
 
     def resolve(self, in_place: bool = True):
@@ -467,18 +434,33 @@ class __ScenarioMeta(ABCMeta, ContextMeta):
     pass
 
 
-class Scenario(Base, ContextBase, metaclass=__ScenarioMeta):
-    pass
+@dataclass
+class Scenario(Base, ContextBase, ABC, metaclass=__ScenarioMeta):
+    def __lt__(self, other):
+        if self.__repr__ != other.__repr__:
+            return self.name < other.name
+        return False
+
+    def __repr__(self):
+        if self.name:
+            return self.name
+        else:
+            params = self.as_dict()
+            sorted_keys = sorted(params.keys(), key=lambda x: x.lower())
+            params = ', '.join(
+                [f'{k}:{params[k].__repr__ if isinstance(params[k], Base) else params[k]}' for k in sorted_keys])
+            return self.scenario_type + '(' + params + ')'
 
 
-class RiskMeasureParameter(Base):
+@dataclass
+class RiskMeasureParameter(Base, ABC):
     pass
 
 
 @dataclass
-class InstrumentBase(Base):
+class InstrumentBase(Base, ABC):
 
-    quantity_: InitVar[float] = field(init=False, default=1)
+    quantity_: InitVar[float] = field(default=1, init=False)
 
     @property
     @abstractmethod
@@ -514,15 +496,6 @@ class InstrumentBase(Base):
     def metadata(self, value):
         self.__metadata = value
 
-    def _property_changed(self, prop: str, value):
-        try:
-            if self.__resolution_key:
-                self.__resolution_key = None
-                self.unresolve()
-        except AttributeError:
-            # Can happen during init
-            pass
-
     def from_instance(self, instance):
         self.__resolution_key = None
         super().from_instance(instance)
@@ -538,12 +511,6 @@ class InstrumentBase(Base):
         new_instrument.__resolution_key = resolution_key
         return new_instrument
 
-    def unresolve(self):
-        if self.__resolution_key and self.__unresolved:
-            self.from_instance(self.__unresolved)
-            self.__resolution_key = None
-            self.__unresolved = None
-
 
 @dataclass
 class Market(ABC):
@@ -570,12 +537,6 @@ class Market(ABC):
     def to_dict(self):
         return self.market.to_dict()
 
-    def to_dict(self):
-        return self.market.to_dict()
-
-    def to_dict(self):
-        return self.market.to_dict()
-
 
 class Sentinel:
 
@@ -623,18 +584,3 @@ global_config.decoders[Optional[InstrumentBase]] = decode_instrument
 
 global_config.encoders[Market] = encode_dictable
 global_config.encoders[Optional[Market]] = encode_dictable
-
-
-def __decode_dataclass(cls, kvs, infer_missing):
-    # EXTREMELY unfortunate
-    if isinstance(kvs, cls):
-        return kvs
-    elif hasattr(cls, 'decode_dataclass'):
-        return cls.decode_dataclass(kvs)
-    else:
-        from dataclasses_json.core import _decode_dataclass_orig
-        return _decode_dataclass_orig(cls, kvs, infer_missing)
-
-
-dataclasses_json.core._decode_dataclass_orig = dataclasses_json.core._decode_dataclass
-dataclasses_json.core._decode_dataclass = __decode_dataclass
