@@ -13,7 +13,6 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-from dataclasses_json import global_config
 import datetime as dt
 import inspect
 import logging
@@ -21,103 +20,24 @@ import warnings
 from copy import deepcopy
 from typing import Iterable, Optional, Tuple, Union
 
+from dataclasses_json import global_config
 from gs_quant.api.gs.parser import GsParserApi
 from gs_quant.api.gs.risk import GsRiskApi
-from gs_quant.base import get_enum_value, Base, InstrumentBase, Priceable
+from gs_quant.base import get_enum_value, InstrumentBase, Priceable, Scenario
 from gs_quant.common import AssetClass, AssetType, XRef, RiskMeasure
 from gs_quant.markets import HistoricalPricingContext, MarketDataCoordinate, PricingContext
 from gs_quant.priceable import PriceableImpl
 from gs_quant.risk import FloatWithInfo, DataFrameWithInfo, SeriesWithInfo, ResolvedInstrumentValues, \
     DEPRECATED_MEASURES
 from gs_quant.risk.results import ErrorValue, MultipleRiskMeasureFuture, PricingFuture
-from gs_quant.session import GsSession
+from gs_quant.target.common import MultiScenario
 
 _logger = logging.getLogger(__name__)
 
 
-def resolution_safe(cls):
-
-    cls.__dataclass_hash__ = cls.__hash__
-    cls.__hash__ = cls.__hash_safe__
-
-    cls.__dataclass_eq__ = cls.__eq__
-    cls.__eq__ = cls.__eq_safe__
-
-    cls.__dataclass_repr__ = Base.__repr__
-    cls.__repr__ = cls.__repr_safe__
-
-    cls._dataclass_json_to_dict = cls.to_dict
-    cls.to_dict = cls._to_dict_safe
-
-    return cls
-
-
 class Instrument(PriceableImpl, InstrumentBase):
-
     PROVIDER = GsRiskApi
     __instrument_mappings = {}
-    __suppress_resolution = False
-
-    class __SuppressResolutionContext:
-
-        def __init__(self, instrument):
-            self.__suppress_resolution = None
-            self.__instrument = instrument
-
-        def __enter__(self):
-            self.__suppress_resolution = self.__instrument._Instrument__suppress_resolution
-            self.__instrument._Instrument__suppress_resolution = True
-
-        def __exit__(self, exc_type, exc_val, exc_tb):
-            self.__instrument._Instrument__suppress_resolution = self.__suppress_resolution
-
-    def __hash_safe__(self):
-        with Instrument.__SuppressResolutionContext(self):
-            return self.__dataclass_hash__()
-
-    def __eq_safe__(self, other):
-        if not isinstance(other, Instrument):
-            return False
-
-        with Instrument.__SuppressResolutionContext(self), Instrument.__SuppressResolutionContext(other):
-            return self.__dataclass_eq__(other)
-
-    def __repr_safe__(self):
-        with Instrument.__SuppressResolutionContext(self):
-            return self.__dataclass_repr__()
-
-    def _to_dict_safe(self, encode_json: Optional[bool] = False):
-        with Instrument.__SuppressResolutionContext(self):
-            return self._to_dict(encode_json)
-
-    def _to_dict(self, encode_json: Optional[bool]):
-        return self._dataclass_json_to_dict(encode_json=encode_json)
-
-    def clone(self):
-        with Instrument.__SuppressResolutionContext(self):
-            return super().clone()
-
-    def __getattribute__(self, name):
-        ret = super().__getattribute__(name)
-        flds = super().__getattribute__('_fields_by_name')()
-
-        if ret is not None or name not in flds or super().__getattribute__('_Instrument__suppress_resolution'):
-            return ret
-
-        if GsSession.current_is_set and super().__getattribute__('resolution_key') is None:
-            try:
-                self.__suppress_resolution = True
-                resolved_inst = self.resolve(in_place=False)
-                if isinstance(resolved_inst, PricingFuture):
-                    ret = PricingFuture()
-                    resolved_inst.add_done_callback(lambda inst_f: ret.set_result(
-                        object.__getattribute__(inst_f.result(), name)))
-                else:
-                    ret = object.__getattribute__(resolved_inst, name)
-            finally:
-                self.__suppress_resolution = False
-
-        return ret
 
     @classmethod
     def __asset_class_and_type_to_instrument(cls):
@@ -175,6 +95,9 @@ class Instrument(PriceableImpl, InstrumentBase):
         if in_place and is_historical:
             raise RuntimeError('Cannot resolve in place under a HistoricalPricingContext')
 
+        if in_place and len([i for i in Scenario.path if isinstance(i, MultiScenario)]):
+            raise RuntimeError('Cannot resolve in place under a MultiScenario Context')
+
         return self.calc(ResolvedInstrumentValues, fn=handle_result)
 
     def calc(self, risk_measure: Union[RiskMeasure, Iterable[RiskMeasure]], fn=None) \
@@ -261,8 +184,8 @@ class Instrument(PriceableImpl, InstrumentBase):
         if instrument is None:
             builder_type = values.get('$type') or values.get('builder', values.get('defn', {})).get('$type')
             if builder_type:
-                from gs_quant_internal.base import QuotableBuilder
-                return QuotableBuilder.from_dict(values)
+                from gs_quant_internal.base import decode_quill_value
+                return decode_quill_value(values)
 
             asset_class_field = next((f for f in ('asset_class', 'assetClass') if f in values), None)
             if not asset_class_field:
@@ -358,7 +281,6 @@ class DummyInstrument(Instrument):
 
     @dummy_result.setter
     def dummy_result(self, value: Union[str, float]):
-        self._property_changed('dummy_result')
         self.__dummy_result = value
 
     @property
