@@ -15,6 +15,7 @@ under the License.
 """
 import datetime as dt
 import logging
+from dataclasses import dataclass
 from itertools import chain
 from typing import Iterable, Optional, Tuple, Union
 from urllib.parse import quote
@@ -26,7 +27,7 @@ from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.portfolios import GsPortfolioApi
 from gs_quant.base import InstrumentBase
 from gs_quant.common import RiskMeasure
-from gs_quant.instrument import Instrument
+from gs_quant.instrument import Instrument, AssetType
 from gs_quant.markets import HistoricalPricingContext, OverlayMarket, PricingContext, PositionContext
 from gs_quant.priceable import PriceableImpl
 from gs_quant.risk import ResolvedInstrumentValues
@@ -39,6 +40,7 @@ from more_itertools import unique_everseen
 _logger = logging.getLogger(__name__)
 
 
+@dataclass
 class Portfolio(PriceableImpl):
     """A collection of instruments
 
@@ -69,6 +71,31 @@ class Portfolio(PriceableImpl):
         self.__id = None
         self.__quote_id = None
 
+    def _to_records(self):
+        def get_name(obj, idx):
+            if isinstance(obj, InstrumentBase) and hasattr(obj, 'type_'):
+                type_name = obj.type_.name if isinstance(obj.type_, AssetType) else obj.type_
+            else:
+                type_name = 'Portfolio'
+            return f'{type_name}_{idx}' if obj.name is None else obj.name
+
+        stack = [(None, self)]
+        records = []
+        while stack:
+            temp_records = []
+            parent, portfolio = stack.pop()
+            current_record = {} if len(records) == 0 else records.pop(0)
+            for idx, priceable in enumerate(portfolio.__priceables):
+                path = parent + PortfolioPath(idx) if parent is not None else PortfolioPath(idx)
+                priceable_name = get_name(priceable, idx)
+                if isinstance(priceable, Portfolio):
+                    stack.insert(0, (path, priceable))
+                    temp_records.append({**current_record, f'portfolio_name_{len(path) - 1}': priceable_name})
+                else:
+                    temp_records.append({**current_record, 'instrument_name': priceable_name})
+            records.extend(temp_records)
+        return records
+
     def __getitem__(self, item):
         if isinstance(item, (int, slice)):
             return self.__priceables[item]
@@ -371,8 +398,8 @@ class Portfolio(PriceableImpl):
                     records.extend(to_records(priceable))
                 else:
                     as_dict = priceable.as_dict()
-                    if hasattr(priceable, '_type'):
-                        as_dict['$type'] = priceable._type
+                    if not hasattr(priceable, 'asset_class'):
+                        as_dict['$type'] = priceable.type_
 
                     records.append(dict(chain(as_dict.items(),
                                               (('instrument', priceable), ('portfolio', portfolio.name)))))
@@ -548,9 +575,10 @@ class Portfolio(PriceableImpl):
             return instruments
         return self.__priceables if return_priceables else self.all_instruments
 
-    def clone(self):
-        portfolio_clone = Portfolio([p if isinstance(p, InstrumentBase) else p.clone() for p in self.__priceables],
-                                    name=self.name)
+    def clone(self, clone_instruments: bool = False):
+        portfolio_clone = Portfolio(
+            [p.clone(clone_instruments) if isinstance(p, Portfolio) else p.clone() if clone_instruments else p for p in
+             self.__priceables], name=self.name)
         portfolio_clone.__id = self.__id
         portfolio_clone.__quote_id = self.__quote_id
         return portfolio_clone
