@@ -17,8 +17,10 @@ import datetime as dt
 from enum import Enum, auto
 from typing import List, Dict, Tuple, Union
 import pandas as pd
+import numpy as np
 import logging
 import pydash
+import deprecation
 
 from gs_quant.api.gs.risk_models import GsFactorRiskModelApi, GsRiskModelApi
 from gs_quant.base import EnumBase
@@ -26,7 +28,7 @@ from gs_quant.errors import MqValueError, MqRequestError
 from gs_quant.markets.factor import Factor
 from gs_quant.models.risk_model_utils import build_asset_data_map, build_factor_data_map, \
     build_pfp_data_dataframe, get_isc_dataframe, get_covariance_matrix_dataframe, get_closest_date_index, \
-    batch_and_upload_partial_data, risk_model_data_to_json, get_universe_size, batch_and_upload_coverage_data, \
+    batch_and_upload_partial_data, get_universe_size, batch_and_upload_coverage_data, only_factor_data_is_present, \
     upload_model_data, validate_factors_exist
 from gs_quant.target.risk_models import RiskModel as RiskModelBuilder, RiskModelEventType, RiskModelData, \
     RiskModelCalendar, RiskModelDataAssetsRequest as DataAssetsRequest, RiskModelDataMeasure as Measure, \
@@ -368,8 +370,10 @@ class MarqueeRiskModel(RiskModel):
                          start_date: dt.date = None,
                          end_date: dt.date = None,
                          factor_names: List[str] = None,
-                         factor_ids: List[str] = None) -> List[Factor]:
-        factors_from_model = self.get_factor_data(start_date=start_date, end_date=end_date, format=ReturnFormat.JSON)
+                         factor_ids: List[str] = None,
+                         factor_type: FactorType = None) -> List[Factor]:
+        factors_from_model = self.get_factor_data(start_date=start_date, end_date=end_date,
+                                                  factor_type=factor_type, format=ReturnFormat.JSON)
 
         name_matches = []
         if not factor_names and not factor_ids:
@@ -663,38 +667,57 @@ class MarqueeRiskModel(RiskModel):
                                                f" for {self.id}, consider batching request")
             raise e
 
-    def upload_data(self, data: Union[RiskModelData, Dict], max_asset_batch_size: int = 20000):
+    def upload_data(self,
+                    data: Union[RiskModelData, Dict],
+                    max_asset_batch_size: int = 20000):
         """ Upload risk model data to existing risk model in Marquee
 
-        :param data: complete risk model data for uploading on given date
-            includes: date, factorData, assetData, covarianceMatrix with optional inputs:
-            issuerSpecificCovariance and factorPortfolios
+        :param data: complete or partial risk model data for uploading on given date
+            includes: date, and one or more of: factorData, assetData, covarianceMatrix,
+                issuerSpecificCovariance and factorPortfolios. Look at risk model upload documentation for
+                further information on what data can be grouped together if asset data size is above the
+                max asset batch size
         :param max_asset_batch_size: size of payload to batch with. Defaults to 20000 assets which works well for
             models that have factor ids ranging from 1- 3 characters in length. For models with longer factor ids,
             consider batching with a smaller max asset batch size
-
         If upload universe is over max_asset_batch_size, will batch data in chunks of max_asset_batch_size assets
+
+        This function takes risk model data, and if partial requests are necessary, will upload data by:
+            1. factor data (includes covariance matrix if factor model)
+            2. asset data in batches of max_asset_batch_size
+            3. issuer specific covariance data in batches of max_asset_batch_size / 2 due to the structure of this data
+            4. factor portfolio data in batches of max_asset_batch_size / 2 due to the structure of this data
+
+        In the case of repeat identifiers on a given data, the repeated data will replace existing data
         """
 
-        data = risk_model_data_to_json(data) if type(data) == RiskModelData else data
-        target_universe_size = get_universe_size(data)
-        logging.info(f'Target universe size for upload: {target_universe_size}')
-        if target_universe_size > max_asset_batch_size:
-            logging.info('Batching uploads due to universe size')
+        data = data.as_dict() if type(data) == RiskModelData else data
+        full_data_present = 'factorData' in data.keys() and 'assetData' in data.keys()
+        only_factor_data_present = only_factor_data_is_present(self.type, data)
+        target_universe_size = 0 if only_factor_data_present else get_universe_size(data)
+        make_partial_request = target_universe_size > max_asset_batch_size or not full_data_present
+        if target_universe_size:
+            logging.info(f'Target universe size for upload: {target_universe_size}')
+        if make_partial_request:
             batch_and_upload_partial_data(self.id, data, max_asset_batch_size)
         else:
+            logging.info('Uploading model data in one request')
             upload_model_data(self.id, data)
 
-    def upload_partial_data(self, data: Union[RiskModelData, dict], target_universe_size: float = None):
+    @deprecation.deprecated(deprecated_in="0.9.42", details="Please use upload_data instead")
+    def upload_partial_data(self,
+                            data: Union[RiskModelData, dict],
+                            final_upload: bool = None):
         """ Upload partial risk model data to existing risk model in Marquee
 
         :param data: partial risk model data for uploading on given date
-        :param target_universe_size: the size of the complete universe on date
+        :param final_upload: if this is the last upload for the batched subset of data
 
         The models factorData and covarianceMatrix must be uploaded first on given date if repeats in partial
             upload, newer posted data will replace existing data on upload day
+
         """
-        upload_model_data(self.id, data, partial_upload=True, target_universe_size=target_universe_size)
+        upload_model_data(self.id, data, partial_upload=True, final_upload=final_upload)
 
     def upload_asset_coverage_data(self, date: dt.date = None):
         """ Upload to the coverage dataset for given risk model and date
@@ -706,8 +729,9 @@ class MarqueeRiskModel(RiskModel):
         """
         if not date:
             date = self.get_dates()[-1]
-        gsid_list = self.get_asset_universe(
-            date, assets=DataAssetsRequest('gsid', []), format=ReturnFormat.JSON).get(date)
+        gsid_list = self.get_asset_universe(date,
+                                            assets=DataAssetsRequest(RiskModelUniverseIdentifierRequest.gsid, []),
+                                            format=ReturnFormat.JSON).get(date)
         if not gsid_list:
             raise MqRequestError(404, f'No asset data found on {date}')
         batch_and_upload_coverage_data(date, gsid_list, self.id)
@@ -868,7 +892,7 @@ class FactorRiskModel(MarqueeRiskModel):
             limit_factors=False
         ).get('results')
         universe = pydash.get(results, '0.assetData.universe', [])
-        total_risk = build_asset_data_map(results, universe, 'totalRisk')
+        total_risk = build_asset_data_map(results, universe, 'totalRisk', {})
         if format == ReturnFormat.DATA_FRAME:
             total_risk = pd.DataFrame(total_risk)
         return total_risk
@@ -1106,22 +1130,60 @@ class MacroRiskModel(MarqueeRiskModel):
     def get_universe_sensitivity(self,
                                  start_date: dt.date,
                                  end_date: dt.date = None,
-                                 assets: DataAssetsRequest = DataAssetsRequest(RiskModelUniverseIdentifierRequest.gsid,
-                                                                               []),
+                                 assets: DataAssetsRequest = DataAssetsRequest(
+                                     RiskModelUniverseIdentifierRequest.gsid, []),
+                                 factor_type: FactorType = FactorType.Factor,
                                  get_factors_by_name: bool = False,
-                                 format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Get universe sensitivity data for existing macro risk model
+                                 format: ReturnFormat = ReturnFormat.DATA_FRAME
+                                 ) -> Union[List[Dict], pd.DataFrame]:
+        """ Get universe factor or factor category sensitivity data for existing macro risk model
 
         :param start_date: start date for data request
         :param end_date: end date for data request
         :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+        :factor_type: return universe sensitivity to factors if Factor. Otherwise, return universe sensitivity to factor
+        categories
         :param get_factors_by_name: return results keyed by factor name instead of ID
         :param format: which format to return the results in
 
         :return: sensitivity for assets requested
         """
-        return super().get_universe_exposure(start_date, end_date, assets,
-                                             get_factors_by_name=get_factors_by_name, format=format)
+
+        sensitivity_df = super().get_universe_exposure(start_date, end_date, assets,
+                                                       get_factors_by_name=get_factors_by_name, format=format) \
+            if factor_type == FactorType.Factor else \
+            super().get_universe_exposure(start_date, end_date, assets, get_factors_by_name=get_factors_by_name)
+
+        if factor_type == FactorType.Factor:
+            return sensitivity_df
+
+        factor_data = self.get_factor_data(start_date, end_date)
+        factor_data = factor_data.set_index("name") if get_factors_by_name else factor_data.set_index("identifier")
+        columns = [(factor_data.loc[f, "factorCategory"], f) for f in sensitivity_df.columns.values] \
+            if get_factors_by_name else \
+            [(factor_data.loc[f, "factorCategoryId"], f) for f in sensitivity_df.columns.values]
+        sensitivity_df = sensitivity_df.set_axis(pd.MultiIndex.from_tuples(columns), axis=1)
+
+        factor_categories = list(set(sensitivity_df.columns.get_level_values(0).values))
+        factor_category_sens_df = pd.concat(
+            [sensitivity_df[factor_category].agg(np.sum, axis=1)
+                                            .to_frame()
+                                            .rename(columns={0: factor_category})
+             for factor_category in factor_categories], axis=1
+        )
+
+        if format == ReturnFormat.JSON:
+            factor_category_sens_df = factor_category_sens_df.to_dict(orient='index')
+            factor_category_sens_dict = {}
+
+            for key, value in factor_category_sens_df.items():
+                temp_dict = factor_category_sens_dict.get(key[0], {})
+                temp_dict[key[1]] = value
+                factor_category_sens_dict[key[0]] = temp_dict
+
+            return factor_category_sens_dict
+
+        return factor_category_sens_df
 
     def get_r_squared(self,
                       start_date: dt.date,
