@@ -20,5 +20,5 @@ from .scenarios import MarketDataShockBasedScenario
 from gs_quant.target.portfolios import LiquidityRequest
 from gs_quant.target.risk import LiborFallbackScenario, CarryScenario, CompositeScenario, CurveScenario, IndexCurveShift,\
     LiquidityResponse, MarketDataPattern, MarketDataScenario, MarketDataShock, MarketDataShockType, RiskRequest, RollFwd,\
-    CurveOverlay
+    CurveOverlay, MultiScenario
 from gs_quant.target.measures import *
\ No newline at end of file
