@@ -18,11 +18,11 @@ import logging
 from typing import Iterable, Optional, Union
 
 from gs_quant.base import InstrumentBase, RiskKey
+from gs_quant.risk.measures import PnlExplain
+from gs_quant.target.measures import EqDelta, EqGamma, EqVega
 
 from .core import DataFrameWithInfo, ErrorValue, UnsupportedValue, FloatWithInfo, SeriesWithInfo, StringWithInfo, \
-    sort_values
-from gs_quant.target.measures import EqDelta, EqGamma, EqVega
-from gs_quant.risk.measures import PnlExplain
+    sort_values, MQVSValidatorDefnsWithInfo, MQVSValidatorDefn
 
 _logger = logging.getLogger(__name__)
 __scalar_risk_measures = (EqDelta, EqGamma, EqVega)
@@ -217,6 +217,16 @@ def fixing_table_handler(result: dict, risk_key: RiskKey, _instrument: Instrumen
     return SeriesWithInfo(values, index=dates, risk_key=risk_key, request_id=request_id)
 
 
+def simple_valtable_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                            request_id: Optional[str] = None) -> DataFrameWithInfo:
+    raw_res = result['rows']
+    # simplevaltable's values contain all the information on units which needs to be extracted into the dataframe
+    df = DataFrameWithInfo([(res['label'], res['value']['val']) for res in raw_res], risk_key=risk_key,
+                           request_id=request_id, unit=raw_res[0]['value'].get('unit'))
+    df.columns = ['label', 'value']
+    return df
+
+
 def canonical_projection_table_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
                                        request_id: Optional[str] = None) -> DataFrameWithInfo:
     mappings = (
@@ -302,6 +312,12 @@ def mmapi_table_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
     return __dataframe_handler(coordinates, mappings, risk_key, request_id=request_id)
 
 
+def mqvs_validators_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                            request_id: Optional[str] = None) -> MQVSValidatorDefnsWithInfo:
+    validators = [MQVSValidatorDefn.from_dict(r) for r in result['validators']]
+    return MQVSValidatorDefnsWithInfo(risk_key, tuple(validators), request_id=request_id)
+
+
 def market_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
                    request_id: Optional[str] = None) -> StringWithInfo:
     return StringWithInfo(risk_key, result.get('marketRef'), request_id=request_id)
@@ -312,6 +328,14 @@ def unsupported_handler(_result: dict, risk_key: RiskKey, _instrument: Instrumen
     return UnsupportedValue(risk_key, request_id=request_id)
 
 
+def extract_val_from_dataframe_with_info(df: DataFrameWithInfo, value_key: str = 'value'):
+    result = []
+    for val in df[value_key]:
+        if isinstance(val, float):
+            result.append(FloatWithInfo(value=val, unit=df.unit, risk_key=df.risk_key, request_id=df.request_id))
+    return result
+
+
 result_handlers = {
     'Error': error_handler,
     'IRPCashflowTable': cashflows_handler,
@@ -319,12 +343,14 @@ result_handlers = {
     'Message': message_handler,
     'MDAPITable': mdapi_table_handler,
     'MMAPITable': mmapi_table_handler,
+    'MQVSValidators': mqvs_validators_handler,
     'NumberAndUnit': number_and_unit_handler,
     'RequireAssets': required_assets_handler,
     'Risk': risk_handler,
     'RiskByClass': risk_by_class_handler,
     'RiskVector': risk_vector_handler,
     'FixingTable': fixing_table_handler,
+    'Table': simple_valtable_handler,
     'CanonicalProjectionTable': canonical_projection_table_handler,
     'RiskSecondOrderVector': risk_float_handler,
     'RiskTheta': risk_float_handler,
