@@ -18,7 +18,7 @@ import copy
 
 import pandas as pd
 from gs_quant.common import AssetClass, CurrencyParameter, FiniteDifferenceParameter, StringParameter, \
-    ListOfStringParameter, ListOfNumberParameter, MapParameter, AggregationLevel
+    ListOfStringParameter, ListOfNumberParameter, MapParameter
 from gs_quant.common import ParameterisedRiskMeasure, RiskMeasure
 from gs_quant.target.risk import RiskMeasureType, RiskMeasureUnit
 
@@ -31,7 +31,7 @@ class RiskMeasureWithCurrencyParameter(ParameterisedRiskMeasure):
     def __call__(self, currency=None,  name=None):
         # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
         # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
-        if isinstance(currency, pd.DataFrame):
+        if isinstance(currency, (pd.Series, pd.DataFrame)):
             return self
 
         clone = copy.copy(self)
@@ -54,7 +54,7 @@ class RiskMeasureWithListOfNumberParameter(ParameterisedRiskMeasure):
     def __call__(self, list_of_number=None,  name=None):
         # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
         # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
-        if isinstance(list_of_number, pd.DataFrame):
+        if isinstance(list_of_number, (pd.Series, pd.DataFrame)):
             return self
 
         clone = copy.copy(self)
@@ -77,7 +77,7 @@ class RiskMeasureWithListOfStringParameter(ParameterisedRiskMeasure):
     def __call__(self, list_of_string=None,  name=None):
         # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
         # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
-        if isinstance(list_of_string, pd.DataFrame):
+        if isinstance(list_of_string, (pd.Series, pd.DataFrame)):
             return self
 
         clone = copy.copy(self)
@@ -100,7 +100,7 @@ class RiskMeasureWithMapParameter(ParameterisedRiskMeasure):
     def __call__(self, map=None,  name=None):
         # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
         # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
-        if isinstance(map, pd.DataFrame):
+        if isinstance(map, (pd.Series, pd.DataFrame)):
             return self
 
         clone = copy.copy(self)
@@ -123,7 +123,7 @@ class RiskMeasureWithStringParameter(ParameterisedRiskMeasure):
     def __call__(self, string=None,  name=None):
         # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
         # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
-        if isinstance(string, pd.DataFrame):
+        if isinstance(string, (pd.Series, pd.DataFrame)):
             return self
 
         clone = copy.copy(self)
@@ -170,7 +170,7 @@ class RiskMeasureWithFiniteDifferenceParameter(ParameterisedRiskMeasure):
     def __call__(self, aggregation_level=None,  bump_size=None,  currency=None,  finite_difference_method=None,  local_curve=None,  mkt_marking_options=None,  scale_factor=None,  name=None):
         # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
         # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
-        if isinstance(aggregation_level, pd.DataFrame):
+        if isinstance(aggregation_level, (pd.Series, pd.DataFrame)):
             return self
 
         clone = copy.copy(self)
@@ -260,16 +260,16 @@ DollarPrice.__doc__ = "Price of the instrument in US Dollars"
 EqAnnualImpliedVol = RiskMeasure(name="EqAnnualImpliedVol", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Annual Implied Volatility"), unit=RiskMeasureUnit("Percent"))
 EqAnnualImpliedVol.__doc__ = "Equity Annual Implied Volatility (%)"
 
-EqDelta = RiskMeasure(name="EqDelta", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Delta"))
-EqDelta.__doc__ = "Change in Dollar Price (USD present value) due to individual $1 moves in the spot price of underlying equity security"
+EqDelta = RiskMeasureWithCurrencyParameter(name="EqDelta", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Delta"))
+EqDelta.__doc__ = "Change in Dollar Price (USD present value) due to individual 1% move in the spot price of underlying equity security"
 
-EqGamma = RiskMeasure(name="EqGamma", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Gamma"))
-EqGamma.__doc__ = "Change in EqDelta for a $1 shift in the price of the underlying equity security"
+EqGamma = RiskMeasureWithCurrencyParameter(name="EqGamma", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Gamma"))
+EqGamma.__doc__ = "Change in EqDelta for a 1% move in the price of the underlying equity security"
 
 EqSpot = RiskMeasure(name="EqSpot", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Spot"))
 EqSpot.__doc__ = "Equity Spot"
 
-EqVega = RiskMeasure(name="EqVega", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Vega"))
+EqVega = RiskMeasureWithCurrencyParameter(name="EqVega", asset_class=AssetClass("Equity"), measure_type=RiskMeasureType("Vega"))
 EqVega.__doc__ = "Change in Dollar Price (USD present value) due to individual 1bp moves in the implied volatility of the underlying equity security"
 
 FXAnnualATMImpliedVol = RiskMeasure(name="FXAnnualATMImpliedVol", asset_class=AssetClass("FX"), measure_type=RiskMeasureType("Annual ATM Implied Volatility"), unit=RiskMeasureUnit("Percent"))
@@ -332,6 +332,9 @@ FXSpot.__doc__ = "FX spot reference"
 FXVega = RiskMeasureWithFiniteDifferenceParameter(name="FXVega", asset_class=AssetClass("FX"), measure_type=RiskMeasureType("Vega"))
 FXVega.__doc__ = "Change in Dollar Price due to a 1 vol move in the implied volatility of ATM instruments used to build the volatility surface"
 
+FairPremium = RiskMeasureWithCurrencyParameter(name="FairPremium", measure_type=RiskMeasureType("FairPremium"))
+FairPremium.__doc__ = "Fair Premium is the instrument present value discounted to the premium settlement date"
+
 FairPrice = RiskMeasure(name="FairPrice", asset_class=AssetClass("Commod"), measure_type=RiskMeasureType("Fair Price"))
 FairPrice.__doc__ = "FairPrice"
 
