@@ -20,6 +20,10 @@ from pandas.testing import assert_series_equal
 from gs_quant.timeseries.datetime import *
 
 
+def test_basic():
+    assert type(RelativeDate('0d').apply_rule()) == dt.date
+
+
 def test_align():
     dates1 = [
         date(2019, 1, 1),
@@ -462,12 +466,12 @@ def test_bucketize():
 
 
 def test_day_count():
-    assert day_count(datetime.date(2021, 5, 7), datetime.date(2021, 5, 10)) == 1
-    assert day_count(datetime.date(2021, 5, 10), datetime.date(2021, 5, 14)) == 4
-    assert day_count(datetime.date(2021, 5, 10), datetime.date(2021, 5, 17)) == 5
+    assert day_count(dt.date(2021, 5, 7), dt.date(2021, 5, 10)) == 1
+    assert day_count(dt.date(2021, 5, 10), dt.date(2021, 5, 14)) == 4
+    assert day_count(dt.date(2021, 5, 10), dt.date(2021, 5, 17)) == 5
 
     with pytest.raises(MqValueError):
-        day_count(datetime.date(2021, 5, 7), '2021-05-10')
+        day_count(dt.date(2021, 5, 7), '2021-05-10')
 
 
 if __name__ == "__main__":
